[![codecov](https://codecov.io/gh/laminlabs/lamindb-setup/branch/main/graph/badge.svg)](https://codecov.io/gh/laminlabs/lamindb-setup)

# lamindb-setup: Setup LaminDB

- User [docs](https://lamin.ai/docs)
- Developer [docs](https://lamindb-setup-htry.netlify.app/)
